@@ -1,18 +1,16 @@
-import warnings
-
-import diffcp.cones as cone_lib
-
-import numpy as np
-import scipy.sparse as sparse
-import scipy.sparse.linalg as splinalg
-import scs
-import ecos
-from threadpoolctl import threadpool_limits
-
 import multiprocessing as mp
+import warnings
 from multiprocessing.pool import ThreadPool
 
+import ecos
+import numpy as np
+import scipy.sparse as sparse
+import scs
+from distutils.version import StrictVersion
+from threadpoolctl import threadpool_limits
+
 import _diffcp
+import diffcp.cones as cone_lib
 
 
 def pi(z, cones):
@@ -257,6 +255,21 @@ def solve_and_derivative_internal(A, b, c, cone_dict, solve_method=None,
             solve_method = "ECOS"
 
     if solve_method == "SCS":
+
+        # SCS versions SCS 2.*
+        if StrictVersion(scs.__version__) < StrictVersion('3.0.0'):
+            if "eps_abs" in kwargs or "eps_rel" in kwargs:
+                # Take the min of eps_rel and eps_abs to be eps
+                kwargs["eps"] = min(kwargs.get("eps_abs", 1),
+                                    kwargs.get("eps_rel", 1))
+
+        # SCS version 3.*
+        else:
+            if "eps" in kwargs:  # eps replaced by eps_abs, eps_rel
+                kwargs["eps_abs"] = kwargs["eps"]
+                kwargs["eps_rel"] = kwargs["eps"]
+                del kwargs["eps"]
+
         data = {
             "A": A,
             "b": b,
@@ -272,15 +285,16 @@ def solve_and_derivative_internal(A, b, c, cone_dict, solve_method=None,
         result = scs.solve(data, cone_dict, **kwargs)
 
         status = result["info"]["status"]
-        if status == "Solved/Inaccurate" and "acceleration_lookback" not in kwargs:
+        inaccurate_status = {"Solved/Inaccurate", "solved (inaccurate - reached max_iters)"}
+        if status in inaccurate_status and "acceleration_lookback" not in kwargs:
             # anderson acceleration is sometimes unstable
             result = scs.solve(
                 data, cone_dict, acceleration_lookback=0, **kwargs)
             status = result["info"]["status"]
 
-        if status == "Solved/Inaccurate":
+        if status in inaccurate_status:
             warnings.warn("Solved/Inaccurate.")
-        elif status != "Solved":
+        elif status.lower() != "solved":
             if raise_on_error:
                 raise SolverError("Solver scs returned status %s" % status)
             else:
@@ -302,7 +316,7 @@ def solve_and_derivative_internal(A, b, c, cone_dict, solve_method=None,
             raise NotImplementedError("Exponential cones not supported yet.")
         if warm_start is not None:
             raise ValueError("ECOS does not support warm starting.")
-        len_eq = cone_dict["f"]
+        len_eq = cone_dict[cone_lib.EQ_DIM]
         C_ecos = c
         G_ecos = A[len_eq:]
         if 0 in G_ecos.shape:
@@ -340,11 +354,27 @@ def solve_and_derivative_internal(A, b, c, cone_dict, solve_method=None,
         status = solution["info"]["exitFlag"]
         STATUS_LOOKUP = {0: "Optimal", 1: "Infeasible", 2: "Unbounded", 10: "Optimal Inaccurate",
                          11: "Infeasible Inaccurate", 12: "Unbounded Inaccurate"}
-        if status < 0:
+
+        if status == 10:
+            warnings.warn("Solved/Inaccurate.")
+        elif status < 0:
             raise SolverError("Solver ecos errored.")
-        if status != 0:
+        if status not in [0, 10]:
             raise SolverError("Solver ecos returned status %s" %
                               STATUS_LOOKUP[status])
+
+        # Convert ECOS info into SCS info to be compatible if called from
+        # CVXPY DIFFCP solver
+        ECOS2SCS_STATUS_MAP = {0: "Solved", 1: "Infeasible", 2: "Unbounded",
+                               10: "Solved/Inaccurate",
+                               11: "Infeasible/Inaccurate",
+                               12: "Unbounded/Inaccurate"}
+        result['info'] = {'status': ECOS2SCS_STATUS_MAP.get(status, "Failure"),
+                          'solveTime': solution['info']['timing']['tsolve'],
+                          'setupTime': solution['info']['timing']['tsetup'],
+                          'iter': solution['info']['iter'],
+                          'pobj': solution['info']['pcost']}
+
     else:
         raise ValueError("Solver %s not supported." % solve_method)
 
